@@ -1,6 +1,18 @@
 # -*- coding: utf-8 -*-
 """Page Admin module."""
-from os.path import join
+from pages import settings
+from pages.models import Page, Content, PageAlias
+from pages.http import get_language_from_request, get_template_from_request
+from pages.utils import get_placeholders
+from pages.utils import get_language_from_request
+from pages.templatetags.pages_tags import PlaceholderNode
+from pages.admin.utils import get_connected, make_inline_admin
+from pages.admin.forms import PageForm
+from pages.admin.views import traduction, get_content, sub_menu, list_pages_ajax
+from pages.admin.views import change_status, modify_content, delete_content
+from pages.permissions import PagePermission
+from pages.http import auto_render
+import pages.widgets
 
 from django.contrib import admin
 from django.utils.translation import ugettext as _, ugettext_lazy
@@ -9,19 +21,13 @@ from django.conf import settings as global_settings
 from django.http import HttpResponseRedirect
 from django.contrib.admin.util import unquote
 from django.contrib.admin.sites import AlreadyRegistered
+if global_settings.USE_I18N:
+    from django.views.i18n import javascript_catalog
+else:
+    from django.views.i18n import null_javascript_catalog as javascript_catalog
 
-from pages import settings
-from pages.models import Page, Content, PageAlias
-from pages.http import get_language_from_request, get_template_from_request
+from os.path import join
 
-from pages.utils import get_placeholders
-from pages.utils import has_page_add_permission, get_language_from_request
-from pages.templatetags.pages_tags import PlaceholderNode
-from pages.admin.utils import get_connected, make_inline_admin
-from pages.admin.forms import PageForm
-from pages.admin.views import traduction, get_content, sub_menu
-from pages.admin.views import change_status, modify_content, delete_content
-import pages.admin.widgets
 
 class PageAdmin(admin.ModelAdmin):
     """Page Admin class."""
@@ -30,11 +36,11 @@ class PageAdmin(admin.ModelAdmin):
     exclude = ['author', 'parent']
     # these mandatory fields are not versioned
     mandatory_placeholders = ('title', 'slug')
-    general_fields = ['title', 'slug', 'status', 'target', 'position']
+    general_fields = ['title', 'slug', 'status', 'target',
+        'position', 'freeze_date']
 
-    # TODO: find solution to do this dynamically
-    #if getattr(settings, 'PAGE_USE_SITE_ID'):
-    general_fields.append('sites')
+    if settings.PAGE_USE_SITE_ID:
+        general_fields.append('sites')
     insert_point = general_fields.index('status') + 1
     
     # Strange django behavior. If not provided, django will try to find
@@ -62,10 +68,10 @@ class PageAdmin(admin.ModelAdmin):
     normal_fields.append('redirect_to')
     normal_fields.append('redirect_to_url')
     fieldsets = (
-        (_('General'), {
+        [_('General'), {
             'fields': general_fields,
             'classes': ('module-general',),
-        }),
+        }],
         (_('Options'), {
             'fields': normal_fields,
             'classes': ('module-options',),
@@ -121,17 +127,12 @@ class PageAdmin(admin.ModelAdmin):
         This takes into account the ``USE_I18N`` setting. If it's set to False, the
         generated JavaScript will be leaner and faster.
         """
-        if global_settings.USE_I18N:
-            from django.views.i18n import javascript_catalog
-        else:
-            from django.views.i18n import null_javascript_catalog as javascript_catalog
         return javascript_catalog(request, packages='pages')
 
     def save_model(self, request, page, form, change):
         """Move the page in the tree if necessary and save every
         placeholder :class:`Content <pages.models.Content>`.
         """
-
         language = form.cleaned_data['language']
         target = form.data.get('target', None)
         position = form.data.get('position', None)
@@ -165,7 +166,21 @@ class PageAdmin(admin.ModelAdmin):
         Add fieldsets of placeholders to the list of already
         existing fieldsets.
         """
-        additional_fieldsets = []
+        general_fields = list(self.general_fields)
+        perms = PagePermission(request.user)
+
+        # some ugly business to remove freeze_date
+        # from the field list
+        general_module = {
+            'fields': list(self.general_fields),
+            'classes': ('module-general',),
+        }
+        
+        default_fieldsets = list(self.fieldsets)
+        if not perms.check('freeze'):
+            general_module['fields'].remove('freeze_date')
+
+        default_fieldsets[0][1] = general_module
 
         placeholder_fieldsets = []
         template = get_template_from_request(request, obj)
@@ -173,16 +188,13 @@ class PageAdmin(admin.ModelAdmin):
             if placeholder.name not in self.mandatory_placeholders:
                 placeholder_fieldsets.append(placeholder.name)
 
+        additional_fieldsets = []
         additional_fieldsets.append((_('Content'), {
             'fields': placeholder_fieldsets,
             'classes': ('module-content',),
         }))
 
-        # deactived for now, create bugs with page with same slug title
-
-        given_fieldsets = list(self.declared_fieldsets)
-
-        return given_fieldsets + additional_fieldsets
+        return default_fieldsets + additional_fieldsets
 
     def save_form(self, request, form, change):
         """Given a ModelForm return an unsaved instance. ``change`` is True if
@@ -223,7 +235,8 @@ class PageAdmin(admin.ModelAdmin):
                 initial = Content.objects.get_content(obj, language, name)
             else:
                 initial = None
-            form.base_fields[name] = placeholder.get_field(obj, language, initial=initial)
+            form.base_fields[name] = placeholder.get_field(obj,
+                language, initial=initial)
 
         return form
 
@@ -268,39 +281,33 @@ class PageAdmin(admin.ModelAdmin):
     def has_add_permission(self, request):
         """Return ``True`` if the current user has permission to add a new
         page."""
-        if not settings.PAGE_PERMISSION:
-            return super(PageAdmin, self).has_add_permission(request)
-        else:
-            return has_page_add_permission(request)
+        lang = get_language_from_request(request)
+        return PagePermission(request.user).check('add', lang=lang)
 
     def has_change_permission(self, request, obj=None):
-        """Return ``True`` if the current user has permission on the page.
-        Return the string ``All`` if the user has all rights."""
-        if settings.PAGE_PERMISSION and obj is not None:
-            return obj.has_page_permission(request)
-        return super(PageAdmin, self).has_change_permission(request, obj)
+        """Return ``True`` if the current user has permission
+        to change the page."""
+        lang = get_language_from_request(request)
+        return PagePermission(request.user).check('change', page=obj,
+            lang=lang, method=request.method)
 
     def has_delete_permission(self, request, obj=None):
-        """Return ``True``  if the current user has permission on the page.
-        Return the string ``All`` if the user has all rights.
-        """
-        if settings.PAGE_PERMISSION and obj is not None:
-            return obj.has_page_permission(request)
-        return super(PageAdmin, self).has_delete_permission(request, obj)
+        """Return ``True`` if the current user has permission on the page."""
+        lang = get_language_from_request(request)
+        return PagePermission(request.user).check('change', page=obj,
+            lang=lang)
 
     def list_pages(self, request, template_name=None, extra_context=None):
         """List root pages"""
         if not admin.site.has_permission(request):
             return admin.site.login(request)
-        # HACK: overrides the changelist template and later resets it to None
-        if template_name:
-            self.change_list_template = template_name
         language = get_language_from_request(request)
 
-        q=request.POST.get('q', '').strip()
+        query = request.POST.get('q', '').strip()
 
-        if q:
-            page_ids = list(set([c.page.pk for c in Content.objects.filter(body__icontains=q)]))
+        if query:
+            page_ids = list(set([c.page.pk for c in
+                Content.objects.filter(body__icontains=q)]))
             pages = Page.objects.filter(pk__in=page_ids)
         else:
             pages = Page.objects.root()
@@ -310,13 +317,16 @@ class PageAdmin(admin.ModelAdmin):
             'name': _("page"),
             'pages': pages,
             'opts': self.model._meta,
-            'q': q
+            'q': query
         }
 
+        # sad hack for ajax
+        # if template_name:
+        #    self.change_list_template = template_name
         context.update(extra_context or {})
         change_list = self.changelist_view(request, context)
-
-        self.change_list_template = None
+        #self.change_list_template = 'admin/pages/page/change_list.html'
+        #
         return change_list
 
     def move_page(self, request, page_id, extra_context=None):
@@ -338,12 +348,11 @@ class PageAdmin(admin.ModelAdmin):
                 page.invalidate()
                 target.invalidate()
                 page.move_to(target, position)
-                return self.list_pages(request,
-                    template_name='admin/pages/page/change_list_table.html')
+                return list_pages_ajax(request)
         return HttpResponseRedirect('../../')
 
-for model, options in get_connected():
-    PageAdmin.inlines.append(make_inline_admin(model, options))
+for admin_class, model, options in get_connected():
+    PageAdmin.inlines.append(make_inline_admin(admin_class, model, options))
 
 try:
     admin.site.register(Page, PageAdmin)
@@ -357,13 +366,6 @@ class ContentAdmin(admin.ModelAdmin):
 
 #admin.site.register(Content, ContentAdmin)
 
-if settings.PAGE_PERMISSION:
-    from pages.models import PagePermission
-    try:
-        admin.site.register(PagePermission)
-    except AlreadyRegistered:
-        pass
-
 class AliasAdmin(admin.ModelAdmin):
     list_display = ('page', 'url',)
     list_editable = ('url', )
