@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 """Django page CMS test suite module"""
+import datetime
+
 import django
+from django.contrib.auth.models import User
 from django.conf import settings
 from django.test.client import Client
-from django.template import Template, RequestContext, TemplateDoesNotExist
+from django.template import Template, RequestContext, Context, TemplateDoesNotExist
 from django.http import HttpResponse, HttpResponseRedirect
 from django.shortcuts import render_to_response
 
@@ -16,8 +19,8 @@ class PagesTestCase(TestCase):
     def test_add_page(self):
         """Test that the add admin page could be displayed via the
         admin"""
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        
         response = c.get('/admin/pages/page/add/')
         self.assertEqual(response.status_code, 200)
 
@@ -25,8 +28,8 @@ class PagesTestCase(TestCase):
     def test_create_page(self):
         """Test that a page can be created via the admin."""
         #setattr(settings, "SITE_ID", 2)
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+
         page_data = self.get_new_page_data()
         response = c.post('/admin/pages/page/add/', page_data)
         self.assertRedirects(response, '/admin/pages/page/')
@@ -43,8 +46,8 @@ class PagesTestCase(TestCase):
         """Test a slug collision."""
         setattr(settings, "PAGE_UNIQUE_SLUG_REQUIRED", True)
 
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        
         page_data = self.get_new_page_data()
         response = c.post('/admin/pages/page/add/', page_data)
         self.assertRedirects(response, '/admin/pages/page/')
@@ -63,8 +66,8 @@ class PagesTestCase(TestCase):
     def test_details_view(self):
         """Test the details view"""
 
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+
         try:
             response = c.get('/pages/')
         except TemplateDoesNotExist, e:
@@ -92,8 +95,8 @@ class PagesTestCase(TestCase):
 
     def test_edit_page(self):
         """Test that a page can edited via the admin"""
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         response = c.post('/admin/pages/page/add/', page_data)
         self.assertRedirects(response, '/admin/pages/page/')
@@ -118,8 +121,8 @@ class PagesTestCase(TestCase):
         setattr(pages_settings, "SITE_ID", 2)
         setattr(pages_settings, "PAGE_USE_SITE_ID", True)
 
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         page_data["sites"] = [2]
         response = c.post('/admin/pages/page/add/', page_data)
@@ -173,16 +176,17 @@ class PagesTestCase(TestCase):
     def test_languages(self):
         """Test post a page with different languages
         and test that the admin views works correctly."""
-        c = Client()
-        user = c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        user = c.login(username='batiste', password='b')
         
         # test that the client language setting is used in add page admin
         c.cookies["django_language"] = 'de'
         response = c.get('/admin/pages/page/add/')
-        self.assertContains(response, 'value="de" selected="selected"')
+        
+        self.assertContains(response, 'value="de"')
         c.cookies["django_language"] = 'fr-ch'
         response = c.get('/admin/pages/page/add/')
-        self.assertContains(response, 'value="fr-ch" selected="selected"')
+        self.assertContains(response, 'value="fr-ch"')
 
         page_data = self.get_new_page_data()
         page_data["title"] = 'english title'
@@ -200,7 +204,7 @@ class PagesTestCase(TestCase):
             major, middle = [int(v) for v in django_version]
         if major >= 1 and middle > 0:
             response = c.get('/admin/pages/page/%d/?language=de' % page.id)
-            self.assertContains(response, 'value="de" selected="selected"')
+            self.assertContains(response, 'value="de"')
 
         # add a french version of the same page
         page_data["language"] = 'fr-ch'
@@ -213,14 +217,14 @@ class PagesTestCase(TestCase):
         # test that the frontend view use the good parameters
         # I cannot find a way of setting the accept-language HTTP 
         # header so I used django_language cookie instead
-        c = Client()
+        c = self.get_admin_client()
         c.cookies["django_language"] = 'en-us'
         response = c.get('/pages/')
         self.assertContains(response, 'english title')
         self.assertContains(response, 'lang="en-us"')
         self.assertNotContains(response, 'french title')
         
-        c = Client()
+        c = self.get_admin_client()
         c.cookies["django_language"] = 'fr-ch'
         response = c.get('/pages/')
         self.assertContains(response, 'french title')
@@ -229,7 +233,7 @@ class PagesTestCase(TestCase):
         self.assertNotContains(response, 'english title')
 
         # this should be mapped to the fr-ch content
-        c = Client()
+        c = self.get_admin_client()
         c.cookies["django_language"] = 'fr-fr'
         response = c.get('/pages/')
         self.assertContains(response, 'french title')
@@ -237,8 +241,8 @@ class PagesTestCase(TestCase):
         
     def test_revision(self):
         """Test that a page can edited several times."""
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         response = c.post('/admin/pages/page/add/', page_data)
         page = Page.objects.all()[0]
@@ -264,8 +268,8 @@ class PagesTestCase(TestCase):
         the admin
         """
         setattr(settings, "SITE_ID", 2)
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         page_data['template'] = 'pages/nice.html'
         response = c.post('/admin/pages/page/add/', page_data)
@@ -280,8 +284,8 @@ class PagesTestCase(TestCase):
         Test diretory slugs
         """
         setattr(settings, "PAGE_UNIQUE_SLUG_REQUIRED", False)
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
 
         page_data = self.get_new_page_data()
         page_data['title'] = 'parent title'
@@ -319,8 +323,8 @@ class PagesTestCase(TestCase):
         """
         Test the {% show_content %} template tag
         """
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         response = c.post('/admin/pages/page/add/', page_data)
         page = Page.objects.all()[0]
@@ -340,8 +344,8 @@ class PagesTestCase(TestCase):
         """
         Test the {% get_content %} template tag
         """
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         response = c.post('/admin/pages/page/add/', page_data)
         page = Page.objects.all()[0]
@@ -369,8 +373,8 @@ class PagesTestCase(TestCase):
         Test that moving/creating page in the tree is working properly
         using the admin interface
         """
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         page_data['slug'] = 'root'
 
@@ -449,8 +453,8 @@ class PagesTestCase(TestCase):
         """
         Test that the navigation tree works properly with mptt
         """
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         page_data['slug'] = 'page1'
         response = c.post('/admin/pages/page/add/', page_data)
@@ -496,8 +500,8 @@ class PagesTestCase(TestCase):
     
     def test_ajax_language(self):
         """Test that language is working properly"""
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         # Activate a language other than settings.LANGUAGE_CODE
         response = c.post('/i18n/setlang/', {'language':'fr-ch' })
         self.assertEqual(c.session.get('django_language', False), 'fr-ch')
@@ -556,8 +560,8 @@ class PagesTestCase(TestCase):
         Test that the default view can only return the context
         """
         
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         page_data['slug'] = 'page1'
         # create a page for the example otherwise you will get a Http404 error
@@ -572,8 +576,8 @@ class PagesTestCase(TestCase):
 
     def test_page_valid_targets(self):
         """Test page valid_targets method"""
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         page_data['slug'] = 'root'
         response = c.post('/admin/pages/page/add/', page_data)
@@ -592,8 +596,8 @@ class PagesTestCase(TestCase):
 
     def test_page_admin_view(self):
         """Test page admin view"""
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
         page_data['slug'] = 'page-1'
         response = c.post('/admin/pages/page/add/', page_data)
@@ -624,8 +628,8 @@ class PagesTestCase(TestCase):
     def test_page_alias(self):
         """Test page aliasing system"""
 
-        c = Client()
-        c.login(username= 'batiste', password='b')
+        c = self.get_admin_client()
+        c.login(username='batiste', password='b')
         
         # create some pages
         page_data = self.get_new_page_data()
@@ -666,8 +670,7 @@ class PagesTestCase(TestCase):
     def test_page_redirect_to(self):
         """Test page redirected to an other page."""
 
-        client = Client()
-        client.login(username= 'batiste', password='b')
+        client = self.get_admin_client()
 
         # create some pages
         page1 = self.create_new_page(client)
@@ -683,8 +686,8 @@ class PagesTestCase(TestCase):
     def test_page_redirect_to_url(self):
         """Test page redirected to external url."""
 
-        client = Client()
-        client.login(username= 'batiste', password='b')
+        client = self.get_admin_client()
+        
         page1 = self.create_new_page(client)
         url = 'http://code.google.com/p/django-page-cms/'
         page1.redirect_to_url = url
@@ -695,4 +698,95 @@ class PagesTestCase(TestCase):
         self.assertTrue(response.status_code == 301)
         self.assertTrue(response['Location'] == url)
 
-        
\ No newline at end of file
+    def test_page_freeze_date(self):
+        """Test page freezing feature."""
+        c = self.get_admin_client()
+        page_data = self.get_new_page_data()
+        page_data['title'] = 'before'
+        page_data['slug'] = 'before'
+        response = c.post('/admin/pages/page/add/', page_data)
+        self.assertRedirects(response, '/admin/pages/page/')
+        page = Page.objects.from_path('before', None)
+        self.assertEqual(page.freeze_date, None)
+        limit = datetime.datetime.now()
+        page.freeze_date = limit
+        page.save()
+    
+        page_data['title'] = 'after'
+        page_data['slug'] = 'after'
+        # this post erase the limit
+        response = c.post('/admin/pages/page/%d/' % page.id, page_data)
+        self.assertRedirects(response, '/admin/pages/page/')
+
+        page = Page.objects.from_path('after', None)
+        page.freeze_date = limit
+        self.assertEqual(page.slug(), 'before')
+        page.freeze_date = None
+        page.save()
+        self.assertEqual(page.slug(), 'after')
+        page.freeze_date = limit
+        page.save()
+        self.assertEqual(page.slug(), 'before')
+
+    def test_date_ordering(self):
+        """Test page date ordering feature."""
+        from pages import settings as pages_settings
+        setattr(pages_settings, "PAGE_USE_SITE_ID", False)
+        author = User.objects.all()[0]
+        yesterday = datetime.datetime.now() - datetime.timedelta(days=1)
+        now = datetime.datetime.now()
+        p1 = Page(author=author, status=Page.PUBLISHED, publication_date=now)
+        p1.save()
+        p2 = Page(
+            author=author,
+            publication_date=now,
+            status=Page.PUBLISHED
+        )
+        p2.save()
+        p3 = Page(
+            author=author,
+            publication_date=yesterday,
+            status=Page.PUBLISHED
+        )
+        p3.save()
+
+        p2.move_to(p1, position='first-child')
+        p3.move_to(p1, position='first-child')
+
+        p1 = Page.objects.get(pk=p1.id)
+        p2 = Page.objects.get(pk=p2.id)
+        p3 = Page.objects.get(pk=p3.id)
+        self.assertEqual(
+            [p.id for p in p1.get_children_for_frontend()],
+            [p3.id, p2.id]
+        )
+
+        self.assertEqual(
+            [p.id for p in p1.get_date_ordered_children_for_frontend()],
+            [p2.id, p3.id]
+        )
+
+    def test_placeholder_inherit_content(self):
+        """Test placeholder content inheritance between pages."""
+        from pages import settings as pages_settings
+        setattr(pages_settings, "PAGE_USE_SITE_ID", False)
+        author = User.objects.all()[0]
+        p1 = Page(author=author, status=Page.PUBLISHED)
+        p1.save()
+        Content(page=p1, language='en-us', type='toto',
+            body='parent-content').save()
+        p2 = Page(
+            author=author,
+            status=Page.PUBLISHED
+        )
+        p2.save()
+        template = django.template.loader.get_template('pages/tests/test7.html')
+        context = Context({'current_page': p2, 'lang':'en-us'})
+        self.assertEqual(template.render(context), '')
+        
+        p2.move_to(p1, position='first-child')
+        self.assertEqual(template.render(context), 'parent-content')
+
+        
+        
+        
