@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
-from django.conf.urls.defaults import *
+from django.conf.urls.defaults import url, include, patterns
+from django.conf.urls.defaults import handler404, handler500
 from pages.views import details
 from pages import settings
 
@@ -10,11 +10,9 @@ urlpatterns = patterns('',
 
 if settings.PAGE_USE_LANGUAGE_PREFIX:
     urlpatterns += patterns('',
-        url(r'^(?P<lang>[-\w]+)/(?P<path>.*)$', details,
-            name='pages-details-by-path'),
+        url(r'^(?P<lang>[-\w]+)/(?P<path>.*)$', details, name='pages-details-by-path')
     )
 else:
     urlpatterns += patterns('',
-        url(r'^(?P<path>.*)$', details,
-            name='pages-details-by-path'),
+        url(r'^(?P<path>.*)$', details, name='pages-details-by-path')
     )
\ No newline at end of file
